@@ -20,7 +20,9 @@ use swc_ecma_ast::{
     ModuleDecl, Str,
 };
 use swc_ecma_transforms_base::resolver::resolver_with_mark;
-use swc_ecma_visit::{noop_visit_type, FoldWith, Node, Visit, VisitWith};
+use swc_ecma_visit::{
+    noop_visit_mut_type, noop_visit_type, FoldWith, Node, Visit, VisitMut, VisitMutWith, VisitWith,
+};
 /// Module after applying transformations.
 #[derive(Debug, Clone)]
 pub(crate) struct TransformedModule {
@@ -126,12 +128,14 @@ where
     fn analyze(
         &self,
         file_name: &FileName,
-        data: ModuleData,
+        mut data: ModuleData,
     ) -> Result<(TransformedModule, Vec<(Source, Lrc<FileName>)>), Error> {
         self.run(|| {
             tracing::trace!("transform_module({})", data.fm.name);
             let (id, local_mark, export_mark) = self.scope.module_id_gen.gen(file_name);
 
+            data.module.visit_mut_with(&mut ClearMark);
+
             let mut module = data.module.fold_with(&mut resolver_with_mark(local_mark));
 
             // {
@@ -475,3 +479,13 @@ impl Visit for Es6ModuleDetector {
         }
     }
 }
+
+#[derive(Clone, Copy)]
+struct ClearMark;
+impl VisitMut for ClearMark {
+    noop_visit_mut_type!();
+
+    fn visit_mut_ident(&mut self, ident: &mut Ident) {
+        ident.span.ctxt = SyntaxContext::empty();
+    }
+}
